<template>
  <div
    :style="{ backgroundImage: `url('${$snowflake.appearance.background}')` }"
    class="flex size-full items-center justify-center bg-gray-100 bg-cover bg-center"
  >
    <div class="flex h-[calc(100vh-62px)] max-w-3xl flex-col items-center justify-center gap-10 px-5 md:gap-14">
      <h1 class="text-center text-2xl font-semibold text-white lg:text-5xl">{{ headerTitle }}</h1>
      <template v-if="headerSubtitle">
        <h2 class="text-center text-lg font-light text-white lg:text-2xl">{{ headerSubtitle }}</h2>
      </template>
      <template v-if="linkShortening">
        <form
          class="flex w-full max-w-3xl items-stretch px-4"
          @submit.prevent="submit"
        >
          <FormInput
            id="url"
            class="grow"
          >
            <input
              v-model="form.values.url"
              :placeholder="$t('app.links.form.paste')"
              class="w-full rounded-l-2xl border-0 px-6 py-3 text-lg text-gray-900 placeholder-gray-200 ring-1 ring-inset placeholder:text-gray-400 focus:outline-none focus:ring-2 focus:ring-primary-500 sm:leading-6 md:text-xl"
              name="url"
            />
          </FormInput>
          <button
            v-if="shortened"
            class="block h-full flex-none rounded-r-2xl border-transparent bg-primary-600 px-8 py-3 text-lg text-white hover:bg-primary-700 sm:leading-6 md:text-xl"
            type="button"
            @click.prevent="copyToClipboard"
          >
            {{ $t("app.landing.clipboard") }}
          </button>
          <FormSubmit
            v-else
            :processing="form.isFetching"
            class="block h-full flex-none rounded-r-2xl border-transparent bg-primary-600 px-8 py-3 text-lg text-white hover:bg-primary-700 sm:leading-6 md:text-xl"
          >
            {{ $t("app.links.form.shorten") }}
          </FormSubmit>
        </form>
      </template>
    </div>
  </div>
</template>

<script lang="ts" setup>
import FormInput from "@/js/contexts/form/ui/components/FormInput.vue";
import useForm from "@/js/contexts/shared/composables/useForm";
import FormSubmit from "@/js/contexts/form/ui/components/FormSubmit.vue";
import { useClipboard } from "@vueuse/core";
import useNotification from "@/js/contexts/shared/composables/useNotification";

defineProps<{
  headerTitle: string;
  headerSubtitle: string | null;
  linkShortening: boolean;
}>();

const { t } = useI18n();
const { successNotification, errorNotification } = useNotification();

const form = useForm({
  url: "",
});
const shortened = ref<boolean>(false);

const submit = () => {
  form.post("/api/links", {
    onSuccess: (response) => {
      shortened.value = true;
      form.values.url = response.data.data;
    },
    onError: (e) => {
      errorNotification(e.response?.data?.message ?? t("app.links.create.failed"));
    },
  });
};

const copyToClipboard = () => {
  useClipboard()
    .copy(form.values.url)
    .then(() => {
      form.values.url = "";
      shortened.value = false;
      successNotification(t("app.clipboard.copied"));
    });
};
</script>
